# Markdown Extensions

The basic Markdown specification does not include advanced features such as tables and task lists.  However, many of these are widely used (such as in [GitHub Flavored Markdown](https://help.github.com/articles/github-flavored-markdown/).  Here we list the extensions we include.

Please note that the use of these extensions might make your document less portable -- other Markdown editors/processors might not support them in the same way, or even at all.  We've tried to be selective in choosing the syntax that is most widely used and avaialble.


## GitHub Flavored Markdown (GFM) <small><span class="label label-info">Enhancement</span></small>

Borrowed from the [GitHub Flavored Markdown - User Documentation](https://help.github.com/articles/github-flavored-markdown/)

### Multiple underscores in words

Where Markdown transforms underscores (_) into italics, GFM ignores underscores in words, like this:

<div class="row">
<div class="col-sm-6">

**Markdown**

wow_great_stuff
do_this_and_do_that_and_another_thing.

</div>
<div class="col-sm-6">

**How it looks**

wow_great_stuff  
do_this_and_do_that_and_another_thing.

</div>
</div>

This allows code and names with multiple underscores to render properly. To emphasize a portion of a word, use asterisks (*):  so_*wow*_doge.

### URL autolinking

GFM will autolink standard URLs, so if you want to link to a URL (instead of setting link text), you can simply enter the URL and it will be turned into a link to that URL.

    http://example.com

becomes

http://example.com

### Strikethrough

GFM adds syntax to create strikethrough text, which is missing from standard Markdown.

    ~~Mistaken text.~~

becomes

~~Mistaken text.~~

### Fenced code blocks

Standard Markdown converts text with four spaces at the beginning of each line into a code block; GFM also supports fenced blocks. Just wrap your code in `` ``` `` (as shown below) and you won't need to indent it by four spaces. Note that although fenced code blocks don't have to be preceded by a blank line—unlike indented code blocks—we recommend placing a blank line before them to make the raw Markdown easier to read.
Here's an example:

<div class="row">
<div class="col-xs-6">

**Markdown**

    ```
    This is a _fenced_ code block
      Notice the backticks
    ```

</div>
<div class="col-xs-6">

**How it looks**

```
This is a _fenced_ code block
  Notice the backticks
```

</div>
</div>

Keep in mind that, within lists, you must indent non-fenced code blocks eight spaces to render them properly.

### Syntax highlighting

Code blocks can be taken a step further by adding syntax highlighting. In your fenced block, add an optional language identifier and we'll run it through syntax highlighting. For example, to syntax highlight Ruby code:

<div class="row">
<div class="col-xs-6">

    ```ruby
    # calculate individual element of FFT matrix:  (e ^ (2 pi i k/n))
    # fft_matrix[i][j] = omega(i*j, n)
    #----------------------------------------------------------------
    def omega(k, n)
      Math::E ** Complex(0, 2 * Math::PI * k / n)
    end
    ```

</div>
<div class="col-xs-6">

```ruby
# calculate individual element of FFT matrix:  (e ^ (2 pi i k/n))
# fft_matrix[i][j] = omega(i*j, n)
#----------------------------------------------------------------
def omega(k, n)
  Math::E ** Complex(0, 2 * Math::PI * k / n)
end
```

</div>
</div>

Supported Languages
: actionscript, apacheconf, applescript, aspnet, bash, c, clike, coffeescript, cpp, csharp, css, css-extras, dart, eiffel, elixir, erlang, git, go, handlebars, java, javascript, latex, less, lua, makefile, markdown, markup, matlab, nginx, objectivec, perl, php, php-extras, python, r, ruby, scala, sql, swift, wiki, yaml

### Tables

You can create tables by assembling a list of words and dividing them with hyphens - (for the first row), and then separating each column with a pipe `|` (Versatil Markdown provides tools on the Format menu for creating and editing tables):

<div class="row">
<div class="col-sm-6">

**Markdown**

```
First Header  | Second Header
------------- | -------------
Content Cell  | Content Cell
Content Cell  | Content Cell
```

</div>
<div class="col-sm-6">

**How it looks**

First Header  | Second Header
------------- | -------------
Content Cell  | Content Cell
Content Cell  | Content Cell

</div>
</div>

For aesthetic purposes, you can add extra pipes on the ends:

<div class="row">
<div class="col-sm-6">

```
| First Header  | Second Header |
| ------------- | ------------- |
| Content Cell  | Content Cell  |
| Content Cell  | Content Cell  |
```

</div>
</div>

Note that the dashes at the top don't need to match the length of the header text exactly:

<div class="row">
<div class="col-sm-6">

```
| Name | Description          |
| ------------- | ----------- |
| Help      | Display the help window.|
| Close     | Closes a window     |
```

</div>
</div>

You can also include inline Markdown such as links, bold, italics, or strikethrough:

<div class="row">
<div class="col-sm-6">

```
| Name  | Description                  |
|-------|------------------------------|
| Help  | ~~Display the~~ help window. |
| Close | _Closes_ a window            |
```

</div>
<div class="col-sm-6">

| Name  | Description                  |
|-------|------------------------------|
| Help  | ~~Display the~~ help window. |
| Close | _Closes_ a window            |

</div>
</div>

Finally, by including colons : within the header row, you can define text to be left-aligned, right-aligned, or center-aligned:

<div class="row">
<div class="col-sm-6">

```
| Left-Aligned  | Center Aligned  | Right Aligned |
|---------------|:---------------:|--------------:|
| col 3 is      | some wordy text |         $1600 |
| col 2 is      |    centered     |           $12 |
| zebra stripes |    are neat     |            $1 |
```

</div>
<div class="col-sm-6">

| Left-Aligned  | Center Aligned  | Right Aligned |
|---------------|:---------------:|--------------:|
| col 3 is      | some wordy text |         $1600 |
| col 2 is      |    centered     |           $12 |
| zebra stripes |    are neat     |            $1 |

</div>
</div>

A colon on the left-most side indicates a left-aligned column; a colon on the right-most side indicates a right-aligned column; a colon on both sides indicates a center-aligned column.  With no colons, alignment defaults to left-aligned.


## Task Lists <small><span class="label label-info">Enhancement</span></small>

Task lists are possible, by adding `[ ]` or `[x]` :

<div class="row">
<div class="col-xs-6">

    - [ ] Peanut butter
    - [x] Chocolate
    - [ ] Milk

</div>
<div class="col-xs-6">

- [ ] Peanut butter
- [x] Chocolate
- [ ] Milk

</div>
</div>

## Description Lists <small><span class="label label-info">Enhancement</span></small>

A description list is great for data that consists of a term and a definition.  Versatil Markdown displays it as two columns (as opposed to individual consecutive lines).  This makes it great for simple data lists.

For example:

<div class="row">
<div class="col-sm-6">

```
Basic Hosting
: 2GB plan

IP
: 192.168.12.45

Domain
: example.com

FTP
: webmaster
```

</div>
<div class="col-sm-6">

Basic Hosting
: 2GB plan

IP
: 192.168.12.45

Domain
: example.com

FTP
: webmaster

</div>
</div>

## Superscript, subscript, mark, and insert <small><span class="label label-info">Enhancement</span></small>

<div class="row">
<div class="col-sm-6">

**Markdown**

```
Superscript
: x^2^y^3^

Subscript
: H~2~O

Marked
: ==marked text==

Inserted
: ++inserted text++
```

</div>
<div class="col-xs-6">

**How it looks**

Superscript
: x^2^y^3^

Subscript
: H~2~O

Marked
: ==marked text==

Inserted
: ++inserted text++

</div>
</div>

## Abbreviations <small><span class="label label-info">Enhancement</span></small>

<div class="row">
<div class="col-sm-6">

**Markdown**

```
Example using the HTML abbreviation.

*[HTML]: Hyper Text Markup Language
```

</div>
<div class="col-xs-6">

**How it looks**

Example using the HTML abbreviation.

*[HTML]: Hyper Text Markup Language

</div>
</div>

## Footnotes <small><span class="label label-info">Enhancement</span></small>

Footnotes are supported, following the common syntax:

<div class="row">
<div class="col-sm-6">

**Markdown**

```
Here is a footnote reference,[^1] and another.[^longnote]

[^1]: Here is the footnote.

[^longnote]: Here's one with multiple blocks.

    Subsequent paragraphs are indented to show that they
belong to the previous footnote.

        { some.code }

    The whole paragraph can be indented, or just the first
    line.  In this way, multi-paragraph footnotes work like
    multi-paragraph list items.

This paragraph won't be part of the note, because it
isn't indented.
```

</div>
<div class="col-xs-6">

**How it looks**

Here is a footnote reference,[^1] and another.[^longnote]

[^1]: Here is the footnote.

[^longnote]: Here's one with multiple blocks.

    Subsequent paragraphs are indented to show that they
belong to the previous footnote.

        { some.code }

    The whole paragraph can be indented, or just the first
    line.  In this way, multi-paragraph footnotes work like
    multi-paragraph list items.

This paragraph won't be part of the note, because it
isn't indented.

</div>
</div>

## MathJax, TeX, and LaTeX <small><span class="label label-info">Enhancement</span></small>

**_Make sure you have enabled MathJax in the Preferences in order to display the math correctly._**

Using MathJax, TeX and LaTeX are supported.

<div class="row">
<div class="col-sm-6">

**Markdown**

Use the delimiters `$$` and `$` for TeX.  For LaTeX, use `\\(` and `\\)`.  Note the extra `\`, which ensures that Markdown processes the `\` properly.

```
When $a \ne 0$, there are two solutions to \\(ax^2 + bx + c = 0\\) and they are
$$x = {-b \pm \sqrt{b^2-4ac} \over 2a}.$$
```

</div>
<div class="col-xs-6">

**How it looks**

When $a \ne 0$, there are two solutions to \\(ax^2 + bx + c = 0\\) and they are
$$x = {-b \pm \sqrt{b^2-4ac} \over 2a}.$$

</div>
</div>
