# Markdown Reference

The version of Markdown used by Versatil is based on the [CommonMark](http://commonmark.org) specification.  It provides a high degree of backward compatibility with John Gruber's [original Markdown implementation](http://daringfireball.net/projects/markdown/) as well as "_...a standard, unambiguous syntax specification for Markdown, along with a suite of comprehensive tests..._"  We've also added a few popular extensions, particularly GitHub Flavored Markdown.

This will be a quick, not exhaustive, guide to the Markdown syntax.

## Paragraphs

Paragraphs are simply continuous blocks of text lines.  Each paragraph should have a blank line following it, separating it from the next paragraph (or list, etc).

If you wish to force text to a new line, add two spaces to the end of the preceding line.  
This text is on a new line.

This is how the Markdown looks:

```
Paragraphs are simply continuous blocks of text lines.  Each paragraph should have a blank line following it, separating it from the next paragraph (or list, etc).

If you wish to force text to a new line, add two spaces to the end of it. 
This text is on a new line.
```


## Headers

<div class="row">
<div class="col-xs-6">

**Markdown**

    # Heading Level 1

</div>
<div class="col-xs-6">

**How it looks**

# Heading Level 1

</div>
<div class="col-xs-6">

    ## Heading Level 2

</div>
<div class="col-xs-6">

## Heading Level 2

</div>
<div class="col-xs-6">

    ### Heading Level 3

</div>
<div class="col-xs-6">

### Heading Level 3

</div>
</div>

## Blockquotes

<div class="row">
<div class="col-xs-6">

**Markdown**

    > This is some 
    > blockquoted text 

</div>
<div class="col-xs-6">

**How it looks**

> This is some
> blockquoted text

</div>
</div>

## Lists

Unordered lists can begin with `-`, `*`, or `+`.  Ordered lists begin with a number followed by a period.  Whatever starting number you give will be the starting number of the list.

<div class="row">
<div class="col-xs-6">

**Markdown**

    - Peanut butter
    - Chocolate
    - Milk

</div>
<div class="col-xs-6">

**How it looks**

- Peanut butter
- Chocolate
- Milk

</div>
</div>
<div class="row">
<div class="col-xs-6">

    3. three
    3. four
    
       You can include additional text, indented to the list, by indenting it 3 or 4 spaces.
    
    3. five

</div>
<div class="col-xs-6">

3. three
3. four

   You can include additional text, indented to the list, by indenting it 3 or 4 spaces.

3. five

</div>
</div>

## Code Blocks

Indent text by 4 spaces to make it a code block. The text will not be considered Markdown text, and not processed.

    This **line** has been indented by 4 spaces

## Inline Code

Use single backticks to indicate inline code.

<div class="row">
<div class="col-xs-6">

**Markdown**

    This is an `inline code` span

    And this ``uses  a literal backtick (`) ``


</div>
<div class="col-xs-6">

**How it looks**

This is an `inline code` span

And this ``uses  a literal backtick (`) ``

</div>
</div>

## Horizontal Rules

A horizontal rule consists of 3 or more dashes:

<div class="row">
<div class="col-xs-6">

**Markdown**

    ---


</div>
<div class="col-xs-6">

**How it looks**

---

</div>
</div>


## Emphasis

<div class="row">
<div class="col-xs-6">

**Markdown**

    This is **bolded** text

    And this is _italicized_ text

Versatil Markdown also provides the keyboard shortcuts Cmd-b and Cmd-i for these.

</div>
<div class="col-xs-6">

**How it looks**

This is **bolded** text

And this is _italicized_ text

</div>
</div>


## Links

<div class="row">
<div class="col-xs-6">

**Markdown**

```markdown
[This is an example](http://example.com/ "Title for this link") of an 
inline link, with a title that appears when you hover your mouse 
pointer over it.

[This link](http://example.net/) has no title attribute.
```

</div>
<div class="col-xs-6">

**How it looks**

[This is an example](http://example.com/ "Title for this link") of an inline link, with a title that appears when you hover your mouse pointer over it.

[This link](http://example.net/) has no title attribute.

</div>
</div>

<div class="row">
<div class="col-xs-6">

```markdown
This is [an example][id] reference-style link.  

Then, anywhere in the document, you define your link
label like this, on a line by itself
(which doesn't render visually):

[id]: http://example.com/  "Optional Title Here"
```

</div>
<div class="col-xs-6">

This is [an example][id] reference-style link.  

Then, anywhere in the document, you define your link label like this, on a line by itself (which doesn't render visually):

[id]: http://example.com/  "Optional Title Here"

</div>
</div>


## Images

<div class="row">
<div class="col-xs-6">

![Alt text](pier.jpg "Tristachersee")

```markdown
![Alt text](pier.jpg "Tristachersee")
```

Note that the image will be displayed responsively, but will not grow larger than its defined dimensions.

</div>
<div class="col-xs-6">

![Alt text][img2]

```markdown
![Alt text][img2]

[img2]: tree_frog.jpg "Red Eyed tree frog."
```

You can also use references, just like normal links.

[img2]: tree_frog.jpg "Red Eyed tree frog."

</div>
</div>

## Backslash Escapes

If you need to use a character that normally causes Markdown formatting, such as the asterick `*`, you can "escape it" by preceding it with a backslash, like this: `\*`.

Characters that can be esacaped: `\`, `` ` ``, `*`, `_`, `{`, `}`, `[`, `]`, `(`, `)`, `#`, `+`, `-`, `.`, `!`
